package
Version:
v0.0.0-...-2400502
Opens a new window with list of versions in this module.
Published: Nov 14, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DataList struct {
Item interface{} `json:"item"`
Total int64 `json:"total"`
}
DataList 带有总数的Data结构
type Response struct {
Status int `json:"status"`
Data interface{} `json:"data"`
Msg string `json:"msg"`
Error string `json:"error"`
}
Response 基础序列化器
type TokenData struct {
User interface{} `json:"user"`
Token string `json:"token"`
}
TokenData 带有token的Data结构
Source Files
¶
Click to show internal directories.
Click to hide internal directories.